@@ -13,6 +13,7 @@ class DomainDirectiveFactory(object):
     cpp_classes = {
         'class': (cpp.CPPClassObject, 'class'),
         'struct': (cpp.CPPClassObject, 'class'),
+        'interface': (cpp.CPPClassObject, 'interface'),
         'function': (cpp.CPPFunctionObject, 'function'),
         'friend': (cpp.CPPFunctionObject, 'function'),
         'slot': (cpp.CPPFunctionObject, 'function'),
@@ -21,9 +22,7 @@ class DomainDirectiveFactory(object):
         'using': (cpp.CPPTypeObject, 'type'),
         'union': (cpp.CPPTypeObject, 'type'),
         'namespace': (cpp.CPPTypeObject, 'type'),
-        # Use CPPClassObject for enum values as the cpp domain doesn't have a directive for
-        # enum values and CPPMemberObject requires a type.
-        'enumvalue': (cpp.CPPClassObject, 'member'),
+        'enumvalue': (cpp.CPPEnumeratorObject, 'enumerator'),
         'define': (c.CObject, 'macro')
     }
 
@@ -71,6 +70,11 @@ class NodeFinder(nodes.SparseNodeVisitor):
         # https://github.com/michaeljones/breathe/issues/242
         self.declarator = node
 
+    def visit_desc_signature_line(self, node):
+        # In sphinx 1.5, there is now a desc_signature_line node within the desc_signature
+        # This should be used instead
+        self.declarator = node
+
     def visit_desc_content(self, node):
         self.content = node
 
@@ -166,6 +170,7 @@ class SphinxRenderer(object):
         self.target_handler = target_handler
         self.compound_parser = compound_parser
         self.filter_ = filter_
+        self.project_refids = project_info.project_refids()
         self.context = None
         self.output_defname = True
         # Nesting level for lists.
@@ -176,6 +181,12 @@ class SphinxRenderer(object):
         if self.context.domain == '':
             self.context.domain = self.get_domain()
 
+    def get_refid(self, refid):
+        if self.project_refids:
+            return "%s%s" % (self.project_info.name(), refid)
+        else:
+            return refid
+
     def get_domain(self):
         """Returns the domain for the current node."""
 
@@ -190,7 +201,7 @@ class SphinxRenderer(object):
         node = node_stack[0]
         # An enumvalue node doesn't have location, so use its parent node for detecting
         # the domain instead.
-        if isinstance(node, six.text_type) or node.node_type == "enumvalue":
+        if isinstance(node, six.string_types) or node.node_type == "enumvalue":
             node = node_stack[1]
         filename = get_filename(node)
         if not filename and node.node_type == "compound":
@@ -257,7 +268,12 @@ class SphinxRenderer(object):
         nodes = domain_directive.run()
 
         # Filter out outer class names if we are rendering a member as a part of a class content.
-        signode = nodes[1].children[0]
+        rst_node = nodes[1]
+        finder = NodeFinder(rst_node.document)
+        rst_node.walk(finder)
+
+        signode = finder.declarator
+
         if len(names) > 0 and self.context.child:
             signode.children = [n for n in signode.children if not n.tagname == 'desc_addname']
         return nodes
@@ -269,7 +285,7 @@ class SphinxRenderer(object):
         The default implementation should suffice most of the time.
         """
 
-        refid = "%s%s" % (self.project_info.name(), node.id)
+        refid = self.get_refid(node.id)
         return self.target_handler.create_target(refid)
 
     def title(self, node):
@@ -305,9 +321,14 @@ class SphinxRenderer(object):
         if obj_type is None:
             obj_type = node.kind
         nodes = self.run_domain_directive(obj_type, [declaration.replace('\n', ' ')])
+
         rst_node = nodes[1]
-        signode = rst_node[0]
-        contentnode = rst_node[-1]
+        finder = NodeFinder(rst_node.document)
+        rst_node.walk(finder)
+
+        signode = finder.declarator
+        contentnode = finder.content
+
         update_signature = kwargs.get('update_signature', None)
         if update_signature is not None:
             update_signature(signode, obj_type)
@@ -383,7 +404,7 @@ class SphinxRenderer(object):
             rst_node.children[0].insert(0, doxygen_target)
             return nodes, finder.content
 
-        refid = "%s%s" % (self.project_info.name(), node.refid)
+        refid = self.get_refid(node.refid)
         render_sig = kwargs.get('render_signature', render_signature)
         nodes, contentnode = render_sig(file_data, self.target_handler.create_target(refid),
                                         name, kind)
@@ -554,7 +575,8 @@ class SphinxRenderer(object):
         nodelist = self.render_iterable(node.content_)
         nodelist.extend(self.render_iterable(node.para))
 
-        refid = "%s%s" % (self.project_info.name(), node.refid)
+        refid = self.get_refid(node.refid)
+
         nodelist = [
             self.node_factory.pending_xref(
                 "",
@@ -692,6 +714,7 @@ class SphinxRenderer(object):
             rst_node["label"] = None
             rst_node["nowrap"] = False
             rst_node["docname"] = self.state.document.settings.env.docname
+            rst_node["number"] = None
 
             nodelist.append(rst_node)
 
@@ -832,18 +855,20 @@ class SphinxRenderer(object):
 
         nodelist = self.render_iterable(node.content_)
 
-        refid = "%s%s" % (self.project_info.name(), node.refid)
-        nodelist = [
-            self.node_factory.pending_xref(
-                "",
-                reftype="ref",
-                refdomain="std",
-                refexplicit=True,
-                refid=refid,
-                reftarget=refid,
-                *nodelist
-            )
-        ]
+        refid = self.get_refid(node.refid)
+
+        if refid is not None:
+            nodelist = [
+                self.node_factory.pending_xref(
+                    "",
+                    reftype="ref",
+                    refdomain="std",
+                    refexplicit=True,
+                    refid=refid,
+                    reftarget=refid,
+                    *nodelist
+                )
+            ]
 
         return nodelist
 
@@ -906,7 +931,12 @@ class SphinxRenderer(object):
                     declaration += ", "
                 declaration += parameter.defname
             declaration += ")"
-        return self.render_declaration(node, declaration)
+
+        def update_define_signature(signature, obj_type):
+            if node.initializer and self.project_info.show_define_initializer():
+                signature.extend([self.node_factory.Text(" ")] + self.render(node.initializer))
+
+        return self.render_declaration(node, declaration, update_signature=update_define_signature)
 
     def visit_enum(self, node):
         # Sphinx requires a name to be a valid identifier, so replace anonymous enum name of the
@@ -947,29 +977,45 @@ class SphinxRenderer(object):
         elif declaration.startswith(using):
             declaration = declaration[len(using):]
             obj_type = "using"
+
+        def update_signature(signature, obj_type):
+            """Update the signature node if necessary, e.g. add qualifiers."""
+            prefix = obj_type + ' '
+            annotation = self.node_factory.desc_annotation(prefix, prefix)
+            if signature[0].tagname != 'desc_annotation':
+                signature.insert(0, annotation)
+            else:
+                signature[0] = annotation
+
         return self.render_declaration(node, declaration, objtype=obj_type,
-                                       update_signature=self.update_signature)
+                                       update_signature=update_signature)
+
+    def update_signature_with_initializer(self, signature, node):
+        initializer = node.initializer
+        if initializer:
+            nodes = self.render(initializer)
+            separator = ' '
+            if not nodes[0].startswith('='):
+                separator += '= '
+            signature.append(self.node_factory.Text(separator))
+            signature.extend(nodes)
 
     def visit_variable(self, node):
         declaration = get_definition_without_template_args(node)
         enum = 'enum '
         if declaration.startswith(enum):
             declaration = declaration[len(enum):]
-        return self.render_declaration(node, declaration)
+
+        def update_signature(signature, obj_type):
+            self.update_signature_with_initializer(signature, node)
+        return self.render_declaration(node, declaration, update_signature=update_signature)
 
     def visit_enumvalue(self, node):
         def update_signature(signature, obj_type):
             # Remove "class" from the signature. This is needed because Sphinx cpp domain doesn't
             # have an enum value directive and we use a class directive instead.
             signature.children.pop(0)
-            initializer = node.initializer
-            if initializer:
-                nodes = self.render(initializer)
-                separator = ' '
-                if not nodes[0].startswith('='):
-                    separator += '= '
-                signature.append(self.node_factory.Text(separator))
-                signature.extend(nodes)
+            self.update_signature_with_initializer(signature, node)
         return self.render_declaration(node, objtype='enumvalue', update_signature=update_signature)
 
     def visit_param(self, node):
@@ -980,7 +1026,7 @@ class SphinxRenderer(object):
         if node.type_:
             type_nodes = self.render(node.type_)
             # Render keywords as annotations for consistency with the cpp domain.
-            if len(type_nodes) > 0:
+            if len(type_nodes) > 0 and isinstance(type_nodes[0], six.text_type):
                 first_node = type_nodes[0]
                 for keyword in ['typename', 'class']:
                     if first_node.startswith(keyword + ' '):
@@ -1053,7 +1099,8 @@ class SphinxRenderer(object):
         #
         # If there is no description then render then term by itself
         if nodelist:
-            nodelist[0].children = [term, separator] + nodelist[0].children
+            nodelist[0].insert(0, term)
+            nodelist[0].insert(1, separator)
         else:
             nodelist = [term]
 
@@ -1149,7 +1196,7 @@ class SphinxRenderer(object):
         result = []
         if not self.filter_.allow(self.context.node_stack):
             pass
-        elif isinstance(node, six.text_type):
+        elif isinstance(node, six.string_types):
             result = self.visit_unicode(node)
         else:
             method = SphinxRenderer.methods.get(node.node_type, SphinxRenderer.visit_unknown)
