@@ -6,7 +6,10 @@ from breathe.parser.compound import linkedTextTypeSub, memberdefTypeSub, paramTy
 from breathe.renderer.sphinxrenderer import SphinxRenderer
 from breathe.renderer.filter import OpenFilter
 from docutils import frontend, nodes, parsers, utils
-from sphinx.domains import CPPDomain
+from sphinx.domains.cpp import CPPDomain
+from sphinx.domains.c import CDomain
+
+from nose.tools import eq_
 
 
 sphinx.locale.init([], None)
@@ -50,11 +53,17 @@ class TestParam(paramTypeSub, TestDoxygenNode):
     def __init__(self, **kwargs):
         TestDoxygenNode.__init__(self, paramTypeSub, **kwargs)
 
+class MockConfig(object):
+    cpp_id_attributes = []
+    cpp_paren_attributes = []
+    cpp_index_common_prefix = []
+
 
 class MockState:
     def __init__(self):
-        env = sphinx.environment.BuildEnvironment(None, None, None)
+        env = sphinx.environment.BuildEnvironment(None, None, MockConfig())
         CPPDomain(env)
+        CDomain(env)
         env.temp_data['docname'] = 'mock-doc'
         settings = frontend.OptionParser(
             components=(parsers.rst.Parser,)).get_default_values()
@@ -90,8 +99,8 @@ class MockMaskFactory:
 
 
 class MockContext:
-    def __init__(self, node_stack):
-        self.domain = None
+    def __init__(self, node_stack, domain=None):
+        self.domain = domain
         self.node_stack = node_stack
         self.directive_args = [
             None,  # name
@@ -110,12 +119,19 @@ class MockContext:
 
 
 class MockProjectInfo:
-    def __init__(self):
+    def __init__(self, show_define_initializer=False):
+        self._show_define_initializer = show_define_initializer
         pass
 
     def name(self):
         pass
 
+    def show_define_initializer(self):
+        return self._show_define_initializer
+
+    def project_refids(self):
+        pass
+
 
 class MockTargetHandler:
     def __init__(self):
@@ -202,9 +218,9 @@ def test_find_node():
                     'the number of nodes Text is 2')
 
 
-def render(member_def):
+def render(member_def, domain=None, show_define_initializer=False):
     """Render Doxygen *member_def* with *renderer_class*."""
-    renderer = SphinxRenderer(MockProjectInfo(),
+    renderer = SphinxRenderer(MockProjectInfo(show_define_initializer),
                               None,  # renderer_factory
                               create_node_factory(),
                               None,  # state
@@ -212,7 +228,7 @@ def render(member_def):
                               MockTargetHandler(),
                               None,   # compound_parser
                               OpenFilter())
-    renderer.context = MockContext([member_def])
+    renderer.context = MockContext([member_def], domain)
     return renderer.render(member_def)
 
 
@@ -220,7 +236,7 @@ def test_render_func():
     member_def = TestMemberDef(kind='function', definition='void foo', argsstring='(int)', virt='non-virtual',
                                param=[TestParam(type_=TestLinkedText(content_=[TestMixedContainer(value=u'int')]))])
     signature = find_node(render(member_def), 'desc_signature')
-    assert signature[0] == 'void'
+    assert signature.astext().startswith('void')
     assert find_node(signature, 'desc_name')[0] == 'foo'
     params = find_node(signature, 'desc_parameterlist')
     assert len(params) == 1
@@ -234,6 +250,22 @@ def test_render_typedef():
     assert signature.astext() == 'typedef int foo'
 
 
+def test_render_c_typedef():
+    member_def = TestMemberDef(kind='typedef', definition='typedef unsigned int bar')
+    signature = find_node(render(member_def, domain='c'), 'desc_signature')
+    eq_(signature.astext(), 'typedef unsigned int bar')
+
+
+def test_render_c_function_typedef():
+    member_def = TestMemberDef(kind='typedef', definition='typedef void* (*voidFuncPtr)(float, int)')
+    signature = find_node(render(member_def, domain='c'), 'desc_signature')
+    assert signature.astext().startswith('typedef void*')
+    params = find_node(signature, 'desc_parameterlist')
+    assert len(params) == 2
+    eq_(params[0].astext(), "float")
+    eq_(params[1].astext(), "int")
+
+
 def test_render_using_alias():
     member_def = TestMemberDef(kind='typedef', definition='using foo = int')
     signature = find_node(render(member_def), 'desc_signature')
@@ -245,3 +277,28 @@ def test_render_const_func():
                                virt='non-virtual', const='yes')
     signature = find_node(render(member_def), 'desc_signature')
     assert '_CPPv2NK1fEv' in signature['ids']
+
+
+def test_render_variable_initializer():
+    member_def = TestMemberDef(kind='variable', definition='const int EOF', initializer=TestMixedContainer(value=u'= -1'))
+    signature = find_node(render(member_def), 'desc_signature')
+    assert signature.astext() == 'const int EOF = -1'
+
+
+def test_render_define_initializer():
+    member_def = TestMemberDef(kind='define', name='MAX_LENGTH',
+                               initializer=TestLinkedText(content_=[TestMixedContainer(value=u'100')]))
+    signature_w_initializer = find_node(render(member_def, show_define_initializer=True), 'desc_signature')
+    eq_(signature_w_initializer.astext(), 'MAX_LENGTH 100')
+
+    member_def_no_show = TestMemberDef(kind='define', name='MAX_LENGTH_NO_INITIALIZER',
+                               initializer=TestLinkedText(content_=[TestMixedContainer(value=u'100')]))
+
+    signature_wo_initializer = find_node(render(member_def_no_show, show_define_initializer=False), 'desc_signature')
+    eq_(signature_wo_initializer.astext(), 'MAX_LENGTH_NO_INITIALIZER')
+
+
+def test_render_define_no_initializer():
+    member_def = TestMemberDef(kind='define', name='USE_MILK')
+    signature = find_node(render(member_def), 'desc_signature')
+    assert signature.astext() == 'USE_MILK'
